pub struct ApplyEntry {
pub index: u64,
pub term: u64,
pub command: Command,
}Expand description
A decoded Raft log entry ready for state machine application.
Pairs index / term with the decoded Command so that state machines can
produce ApplyResult { index, .. } without re-reading the original Entry.
Fields
index: u64term: u64command: CommandTrait Implementations
Sourceimpl Clone for ApplyEntry
impl Clone for ApplyEntry
Sourcefn clone(&self) -> ApplyEntry
fn clone(&self) -> ApplyEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApplyEntry
impl Debug for ApplyEntry
Sourceimpl PartialEq for ApplyEntry
impl PartialEq for ApplyEntry
Sourcefn eq(&self, other: &ApplyEntry) -> bool
fn eq(&self, other: &ApplyEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ApplyEntry